@@ -1,11 +1,14 @@
 import inspect
+import json
 from contextlib import ExitStack
 from enum import Enum
 from typing import (
     TYPE_CHECKING,
     Callable,
+    Iterable,
     Iterator,
     List,
+    Mapping,
     NamedTuple,
     Optional,
     Sequence,
@@ -16,7 +19,7 @@ from typing import (
 from typing_extensions import TypeGuard
 
 import dagster._check as check
-from dagster._annotations import public
+from dagster._annotations import experimental, public
 from dagster._core.errors import (
     DagsterInvalidDefinitionError,
     DagsterInvalidInvocationError,
@@ -38,6 +41,7 @@ from .utils import check_valid_name
 
 if TYPE_CHECKING:
     from dagster._core.events.log import EventLogEntry
+    from dagster._core.storage.event_log.base import EventLogRecord
 
 
 @whitelist_for_serdes
@@ -154,6 +158,150 @@ class SensorEvaluationContext:
         return self._repository_name
 
 
+@experimental
+class MultiAssetSensorEvaluationContext(SensorEvaluationContext):
+    """The context object available as the argument to the evaluation function of a :py:class:`dagster.MultiAssetSensorDefinition`.
+
+    Users should not instantiate this object directly. To construct a
+    `MultiAssetSensorEvaluationContext` for testing purposes, use :py:func:`dagster.
+    build_multi_asset_sensor_context`.
+
+    Attributes:
+        instance_ref (Optional[InstanceRef]): The serialized instance configured to run the schedule
+        cursor (Optional[str]): The cursor, passed back from the last sensor evaluation via
+            the cursor attribute of SkipReason and RunRequest. Must be a dictionary of asset key strings to ints
+            that has been converted to a json string
+        last_completion_time (float): DEPRECATED The last time that the sensor was evaluated (UTC).
+        last_run_key (str): DEPRECATED The run key of the RunRequest most recently created by this
+            sensor. Use the preferred `cursor` attribute instead.
+        repository_name (Optional[str]): The name of the repository that the sensor belongs to.
+        instance (Optional[DagsterInstance]): The deserialized instance can also be passed in
+            directly (primarily useful in testing contexts).
+
+    Example:
+
+    .. code-block:: python
+
+        from dagster import multi_asset_sensor, MultiAssetSensorEvaluationContext
+
+        @multi_asset_sensor(asset_keys=[AssetKey("asset_1), AssetKey("asset_2)])
+        def the_sensor(context: MultiAssetSensorEvaluationContext):
+            ...
+
+    """
+
+    def __init__(
+        self,
+        instance_ref: Optional[InstanceRef],
+        last_completion_time: Optional[float],
+        last_run_key: Optional[str],
+        cursor: Optional[str],
+        repository_name: Optional[str],
+        asset_keys: Sequence[AssetKey],
+        instance: Optional[DagsterInstance] = None,
+    ):
+        self._asset_keys = asset_keys
+        self.cursor_has_been_updated = False
+
+        super(MultiAssetSensorEvaluationContext, self).__init__(
+            instance_ref=instance_ref,
+            last_completion_time=last_completion_time,
+            last_run_key=last_run_key,
+            cursor=cursor,
+            repository_name=repository_name,
+            instance=instance,
+        )
+
+    @public
+    def latest_materialization_records_by_key(
+        self, asset_keys: Optional[Sequence[AssetKey]] = None
+    ) -> Mapping[AssetKey, Optional["EventLogRecord"]]:
+        """Fetches the most recent materialization event record for each asset in asset_keys.
+
+        Args:
+            asset_keys (Optional[Sequence[AssetKey]]): list of asset keys to fetch events for. If not specified, the
+                latest materialization will be fetched for all assets the multi_asset_sensor monitors.
+
+        Returns: Mapping of AssetKey to EventLogRecord where the EventLogRecord is the latest materialization event for the asset. If there
+            is no materialization event for the asset, the value in the mapping will be None.
+        """
+        from dagster._core.events import DagsterEventType
+        from dagster._core.storage.event_log.base import EventRecordsFilter
+
+        if asset_keys is None:
+            asset_keys = self._asset_keys
+
+        cursor_dict = json.loads(self.cursor) if self.cursor else {}
+        asset_event_records = {}
+        for a in asset_keys:
+            event_records = self.instance.get_event_records(
+                EventRecordsFilter(
+                    event_type=DagsterEventType.ASSET_MATERIALIZATION,
+                    asset_key=a,
+                    after_cursor=cursor_dict.get(str(a)),
+                ),
+                ascending=False,
+                limit=1,
+            )
+
+            if event_records:
+                asset_event_records[a] = event_records[0]
+            else:
+                asset_event_records[a] = None
+
+        return asset_event_records
+
+    @public
+    def materialization_records_for_key(
+        self, asset_key: AssetKey, limit: int
+    ) -> Iterable["EventLogRecord"]:
+        """Fetches asset materialization event records for asset_key, with the earliest event first.
+
+        Args:
+            asset_key (AssetKey): The asset to fetch materialization events for
+            limit (int): The number of events to fetch
+        """
+        from dagster._core.events import DagsterEventType
+        from dagster._core.storage.event_log.base import EventRecordsFilter
+
+        cursor_dict = json.loads(self.cursor) if self.cursor else {}
+        return self.instance.get_event_records(
+            EventRecordsFilter(
+                event_type=DagsterEventType.ASSET_MATERIALIZATION,
+                asset_key=asset_key,
+                after_cursor=cursor_dict.get(str(asset_key)),
+            ),
+            ascending=True,
+            limit=limit,
+        )
+
+    @public
+    def advance_cursor(
+        self, materialization_records_by_key: Mapping[AssetKey, Optional["EventLogRecord"]]
+    ):
+        """Advances the cursor for a group of AssetKeys based on the EventLogRecord provided for each AssetKey.
+
+        Args:
+            materialization_records_by_key (Mapping[AssetKey, Optional[EventLogRecord]]): Mapping of AssetKeys to EventLogRecord or None. If
+                an EventLogRecord is provided, the cursor for the AssetKey will be updated and future calls to fetch asset materialization events
+                will only fetch events more recent that the EventLogRecord. If None is provided, the cursor for the AssetKey will not be updated.
+        """
+        cursor_dict = json.loads(self.cursor) if self.cursor else {}
+        update_dict = {
+            str(k): v.storage_id if v else cursor_dict.get(str(k))
+            for k, v in materialization_records_by_key.items()
+        }
+        cursor_str = json.dumps(update_dict)
+        self._cursor = check.opt_str_param(cursor_str, "cursor")
+        self.cursor_has_been_updated = True
+
+    @public
+    def advance_all_cursors(self):
+        """Updates the cursor to the most recent materialization event for all assets monitored by the multi_asset_sensor"""
+        materializations_by_key = self.latest_materialization_records_by_key()
+        self.advance_cursor(materializations_by_key)
+
+
 # Preserve SensorExecutionContext for backcompat so type annotations don't break.
 SensorExecutionContext = SensorEvaluationContext
 
@@ -557,14 +705,64 @@ def build_sensor_context(
     )
 
 
+@experimental
+def build_multi_asset_sensor_context(
+    asset_keys: Sequence[AssetKey],
+    instance: Optional[DagsterInstance] = None,
+    cursor: Optional[str] = None,
+    repository_name: Optional[str] = None,
+) -> MultiAssetSensorEvaluationContext:
+    """Builds multi asset sensor execution context using the provided parameters.
+
+    This function can be used to provide a context to the invocation of a multi asset sensor definition. If
+    provided, the dagster instance must be persistent; DagsterInstance.ephemeral() will result in an
+    error.
+
+    Args:
+        asset_keys (Sequence[AssetKey]): The list of asset keys monitored by the sensor
+        instance (Optional[DagsterInstance]): The dagster instance configured to run the sensor.
+        cursor (Optional[str]): A string cursor to provide to the evaluation of the sensor. Must be
+            a dictionary of asset key strings to ints that has been converted to a json string
+        repository_name (Optional[str]): The name of the repository that the sensor belongs to.
+
+    Examples:
+
+        .. code-block:: python
+
+            with instance_for_test() as instance:
+                context = build_multi_asset_sensor_context(asset_keys=[AssetKey("asset_1"), AssetKey("asset_2")], instance=instance)
+                my_asset_sensor(context)
+
+    """
+
+    check.opt_inst_param(instance, "instance", DagsterInstance)
+    check.opt_str_param(cursor, "cursor")
+    check.opt_str_param(repository_name, "repository_name")
+    check.list_param(asset_keys, "asset_keys", of_type=AssetKey)
+    return MultiAssetSensorEvaluationContext(
+        instance_ref=None,
+        last_completion_time=None,
+        last_run_key=None,
+        cursor=cursor,
+        repository_name=repository_name,
+        instance=instance,
+        asset_keys=asset_keys,
+    )
+
+
 AssetMaterializationFunctionReturn = Union[
-    Iterator[Union[RunRequest, SkipReason]], Sequence[RunRequest], RunRequest, SkipReason
+    Iterator[Union[RunRequest, SkipReason]], Sequence[RunRequest], RunRequest, SkipReason, None
 ]
 AssetMaterializationFunction = Callable[
     ["SensorExecutionContext", "EventLogEntry"],
     AssetMaterializationFunctionReturn,
 ]
 
+MultiAssetMaterializationFunction = Callable[
+    ["MultiAssetSensorEvaluationContext"],
+    AssetMaterializationFunctionReturn,
+]
+
 
 class AssetSensorDefinition(SensorDefinition):
     """Define an asset sensor that initiates a set of runs based on the materialization of a given
@@ -661,3 +859,138 @@ class AssetSensorDefinition(SensorDefinition):
     @property
     def asset_key(self):
         return self._asset_key
+
+
+@experimental
+class MultiAssetSensorDefinition(SensorDefinition):
+    """Define an asset sensor that initiates a set of runs based on the materialization of a list of
+    assets.
+
+    Args:
+        name (str): The name of the sensor to create.
+        asset_keys (Sequence[AssetKey]): The asset_keys this sensor monitors.
+        asset_materialization_fn (Callable[[MultiAssetSensorEvaluationContext], Union[Iterator[Union[RunRequest, SkipReason]], RunRequest, SkipReason]]): The core
+            evaluation function for the sensor, which is run at an interval to determine whether a
+            run should be launched or not. Takes a :py:class:`~dagster.MultiAssetSensorEvaluationContext`.
+
+            This function must return a generator, which must yield either a single SkipReason
+            or one or more RunRequest objects.
+        minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
+            between sensor evaluations.
+        description (Optional[str]): A human-readable description of the sensor.
+        job (Optional[Union[GraphDefinition, JobDefinition, UnresolvedAssetJobDefinition]]): The job
+            object to target with this sensor.
+        jobs (Optional[Sequence[Union[GraphDefinition, JobDefinition, UnresolvedAssetJobDefinition]]]):
+            (experimental) A list of jobs to be executed when the sensor fires.
+        default_status (DefaultSensorStatus): Whether the sensor starts as running or not. The default
+            status can be overridden from Dagit or via the GraphQL API.
+    """
+
+    def __init__(
+        self,
+        name: str,
+        asset_keys: Sequence[AssetKey],
+        job_name: Optional[str],
+        asset_materialization_fn: Callable[
+            ["MultiAssetSensorEvaluationContext"],
+            RawSensorEvaluationFunctionReturn,
+        ],
+        minimum_interval_seconds: Optional[int] = None,
+        description: Optional[str] = None,
+        job: Optional[ExecutableDefinition] = None,
+        jobs: Optional[Sequence[ExecutableDefinition]] = None,
+        default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
+    ):
+        self._asset_keys = check.list_param(asset_keys, "asset_keys", AssetKey)
+
+        def _wrap_asset_fn(materialization_fn):
+            def _fn(context):
+                context.cursor_has_been_updated = False
+                result = materialization_fn(context)
+                if result is None:
+                    return
+
+                # because the materialization_fn can yield results (see _wrapped_fn in multi_asset_sensor decorator),
+                # even if you return None in a sensor, it will still cause in inspect.isgenerator(result) == True.
+                # So keep track to see if we actually return any values and should update the cursor
+                runs_yielded = False
+                if inspect.isgenerator(result) or isinstance(result, list):
+                    for item in result:
+                        runs_yielded = True
+                        yield item
+                elif isinstance(result, RunRequest):
+                    runs_yielded = True
+                    yield result
+                elif isinstance(result, SkipReason):
+                    # if result is a SkipReason, we don't update the cursor, so don't set runs_yielded = True
+                    yield result
+
+                if runs_yielded and not context.cursor_has_been_updated:
+                    raise DagsterInvalidDefinitionError(
+                        "Asset materializations have been handled in this sensor, "
+                        "but the cursor was not updated. This means the same materialization events "
+                        "will be handled in the next sensor tick. Use context.advance_cursor or "
+                        "context.advance_all_cursors to update the cursor."
+                    )
+
+            return _fn
+
+        super(MultiAssetSensorDefinition, self).__init__(
+            name=check_valid_name(name),
+            job_name=job_name,
+            evaluation_fn=_wrap_asset_fn(
+                check.callable_param(asset_materialization_fn, "asset_materialization_fn"),
+            ),
+            minimum_interval_seconds=minimum_interval_seconds,
+            description=description,
+            job=job,
+            jobs=jobs,
+            default_status=default_status,
+        )
+
+    def __call__(self, *args, **kwargs):
+
+        if is_context_provided(self._raw_fn):
+            if len(args) + len(kwargs) == 0:
+                raise DagsterInvalidInvocationError(
+                    "Sensor evaluation function expected context argument, but no context argument "
+                    "was provided when invoking."
+                )
+            if len(args) + len(kwargs) > 1:
+                raise DagsterInvalidInvocationError(
+                    "Sensor invocation received multiple arguments. Only a first "
+                    "positional context parameter should be provided when invoking."
+                )
+
+            context_param_name = get_function_params(self._raw_fn)[0].name
+
+            if args:
+                context = check.opt_inst_param(
+                    args[0], context_param_name, MultiAssetSensorEvaluationContext
+                )
+            else:
+                if context_param_name not in kwargs:
+                    raise DagsterInvalidInvocationError(
+                        f"Sensor invocation expected argument '{context_param_name}'."
+                    )
+                context = check.opt_inst_param(
+                    kwargs[context_param_name], context_param_name, SensorEvaluationContext
+                )
+
+            context = context if context else build_multi_asset_sensor_context()
+
+            return self._raw_fn(context)
+
+        else:
+            if len(args) + len(kwargs) > 0:
+                raise DagsterInvalidInvocationError(
+                    "Sensor decorated function has no arguments, but arguments were provided to "
+                    "invocation."
+                )
+
+            return self._raw_fn()  # type: ignore [TypeGuard limitation]
+
+    @public  # type: ignore
+    @property
+    def asset_keys(self):
+        return self._asset_keys
